//----------------------------------------------------------------------------
//   ____  ____
//  /   /\/   /
// /___/  \  /   Vendor: Xilinx
// \   \   \/    Version: $Revision: 1.1 $
//  \   \        Filename: $RCSfile: mpfr_nt_stdint.h,v $
//  /   /        Date Last Modified: $Date: 2011/05/13 12:55:29 $
// /___/   /\    Date Created: 2011
// \   \  /  \
//  \___\/\___\
//
// Device  : N/A
// Library : MPFR
// Purpose : Header file to provide intmax_t and uintmax_t on NT platforms using Visual Studio 2008
// Revision: $Revision: 1.1 $
//
//------------------------------------------------------------------------------
//  (c) Copyright 2011 Xilinx, Inc. All rights reserved.
//
//  This file contains confidential and proprietary information
//  of Xilinx, Inc. and is protected under U.S. and
//  international copyright and other intellectual property
//  laws.
//
//  DISCLAIMER
//  This disclaimer is not a license and does not grant any
//  rights to the materials distributed herewith. Except as
//  otherwise provided in a valid license issued to you by
//  Xilinx, and to the maximum extent permitted by applicable
//  law: (1) THESE MATERIALS ARE MADE AVAILABLE "AS IS" AND
//  WITH ALL FAULTS, AND XILINX HEREBY DISCLAIMS ALL WARRANTIES
//  AND CONDITIONS, EXPRESS, IMPLIED, OR STATUTORY, INCLUDING
//  BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, NON-
//  INFRINGEMENT, OR FITNESS FOR ANY PARTICULAR PURPOSE; and
//  (2) Xilinx shall not be liable (whether in contract or tort,
//  including negligence, or under any other theory of
//  liability) for any loss or damage of any kind or nature
//  related to, arising under or in connection with these
//  materials, including for any direct, or any indirect,
//  special, incidental, or consequential loss or damage
//  (including loss of data, profits, goodwill, or any type of
//  loss or damage suffered as a result of any action brought
//  by a third party) even if such damage or loss was
//  reasonably foreseeable or Xilinx had been advised of the
//  possibility of the same.
//
//  CRITICAL APPLICATIONS
//  Xilinx products are not designed or intended to be fail-
//  safe, or for use in any application requiring fail-safe
//  performance, such as life-support or safety devices or
//  systems, Class III medical devices, nuclear facilities,
//  applications related to the deployment of airbags, or any
//  other applications that could lead to death, personal
//  injury, or severe property or environmental damage
//  (individually and collectively, "Critical
//  Applications"). Customer assumes the sole risk and
//  liability of any use of Xilinx products in Critical
//  Applications, subject only to applicable laws and
//  regulations governing limitations on product liability.
//
//  THIS COPYRIGHT NOTICE AND DISCLAIMER MUST BE RETAINED AS
//  PART OF THIS FILE AT ALL TIMES.
//------------------------------------------------------------------------------
// mpfr_nt_stdint.h: header file to provide intmax_t and uintmax_t on NT platforms using Visual Studio 2008
//
// The C99 standard specifies a header file stdint.h which provides exact width integer types.
// If these are present, MPFR provides functions that take intmax_t and uintmax_t types as input and output.
// These types must be an integer type providing at least 64 bits of precision, signed and unsigned respectively.
//
// Visual Studio 2008 does not provide stdint.h.  This header file provides the missing types to enable MPFR
// to define all of its functions that use intmax_t and uintmax_t.
//
// To use it in a Visual Studio 2008 project, open the project properties, go to C/C++->Advanced, and enter this
// file name in Force Includes.
//
// Do not use this file in any way when compiling on Linux platforms.  Linux's GCC compiler already has proper C99
// support, including a full-featured stdint.h file.
//------------------------------------------------------------------------------

#ifndef __MPFR_NT_STDINT_H
#define __MPFR_NT_STDINT_H

// Make sure that this header file is only used with Visual Studio on NT
#ifdef _MSC_VER

// Don't use this header file if stdint.h is present
#ifndef _STDINT_H

// Define intmax_t and uintmax_t types
typedef   signed long long intmax_t;
typedef unsigned long long uintmax_t;

// Force MPFR to use these types
#define MPFR_USE_INTMAX_T

#endif // _STDINT_H
#endif // _MSC_VER
#endif // __MPFR_NT_STDINT_H
